/* --- CASIO Bluetooth Library --- */
/* --- header File --- */
/* --- 2002/10/12 --- */
/* --- Edited by Daijou Ishioka --- */

/* --- Error Code from Protocol Stack --- */

#define BTERR_SUCCESS				0
#define BTERR_FAILED				1
#define BTERR_PENDING				2
#define BTERR_DISCONNECT			3
#define BTERR_NO_LINK				4
#define BTERR_IN_USE				5
#define BTERR_BUSY					11
#define BTERR_NO_RESOURCES			12
#define BTERR_NOT_FOUND				13
#define BTERR_DEVICE_NOT_FOUND		14
#define BTERR_CONNECTION_FAILED		15
#define BTERR_TIMEOUT				16
#define BTERR_NO_CONNECTION			17
#define BTERR_INVALID_PARAM			18
#define BTERR_IN_PROGRESS			19
#define BTERR_RESTRICTED			20
#define BTERR_INVALID_TYPE			21
#define BTERR_HCI_INIT_ERR			22
#define BTERR_NOT_SUPPORTED			23
#define BTERR_SDP_CONT_STATE		24
#define BTERR_OPEN					30

#define BTERR_STACK_DOWN			103
#define BTERR_ABORT					128
#define BTERR_ALREADY_EXISTS		129
#define BTERR_CANCELLED				130

/* --- Error Code from Library --- */

#define BTERR_LIB_INIT				256
#define BTERR_APP_EXIST				257
#define BTERR_UART_ONOFF			258
#define BTERR_PASSKEY_SETTING		259

#define BTERR_REG_OPEN				300
#define BTERR_REG_WRITE				301
#define BTERR_REG_READ				302
#define BTERR_REG_DELETE			303
#define BTERR_REG_NO_DATA			304
#define BTERR_REG_NOT_FOUND			305

/* --- Device Mode --- */

#define BTMODE_NOT_ACCESSIBLE		0x0000
#define BTMODE_GENERAL_ACCESSIBLE	0x0001
#define BTMODE_LIMITED_ACCESSIBLE	0x0002
#define BTMODE_CONNECTABLE_ONLY		0x0003

/* --- Device Class --- */

/* Group: Major Service Classes. Can be ORed together */
#define BTCOD_LIMITED_DISCOVERABLE_MODE	0x00002000
#define BTCOD_POSITIONING				0x00010000
#define BTCOD_NETWORKING				0x00020000
#define BTCOD_RENDERING					0x00040000
#define BTCOD_CAPTURING					0x00080000
#define BTCOD_OBJECT_TRANSFER			0x00100000
#define BTCOD_AUDIO						0x00200000
#define BTCOD_TELEPHONY					0x00400000
#define BTCOD_INFORMATION				0x00800000

/* Group: Major Device Classes (Select one) */
#define BTCOD_MAJOR_MISCELLANEOUS		0x00000000
#define BTCOD_MAJOR_COMPUTER			0x00000100
#define BTCOD_MAJOR_PHONE				0x00000200
#define BTCOD_MAJOR_LAN_ACCESS_POINT	0x00000300
#define BTCOD_MAJOR_AUDIO				0x00000400
#define BTCOD_MAJOR_PERIPHERAL			0x00000500
#define BTCOD_MAJOR_IMAGING				0x00000600
#define BTCOD_MAJOR_UNCLASSIFIED		0x00001F00

/* Group: Minor Device Class - Computer Major class */
#define BTCOD_MINOR_COMP_UNCLASSIFIED	0x00000000
#define BTCOD_MINOR_COMP_DESKTOP		0x00000004
#define BTCOD_MINOR_COMP_SERVER			0x00000008
#define BTCOD_MINOR_COMP_LAPTOP			0x0000000C
#define BTCOD_MINOR_COMP_HANDHELD		0x00000010
#define BTCOD_MINOR_COMP_PALM			0x00000014
#define BTCOD_MINOR_COMP_WEARABLE		0x00000018

/* Group: Minor Device Class - Phone Major class */
#define BTCOD_MINOR_PHONE_UNCLASSIFIED	0x00000000
#define BTCOD_MINOR_PHONE_CELLULAR		0x00000004
#define BTCOD_MINOR_PHONE_CORDLESS		0x00000008
#define BTCOD_MINOR_PHONE_SMART			0x0000000C
#define BTCOD_MINOR_PHONE_MODEM			0x00000010

/* Group: Minor Device Class - LAN Access Point Major class */
#define BTCOD_MINOR_LAN_0				0x00000000	/* fully available */
#define BTCOD_MINOR_LAN_17				0x00000020	/* 1-17% utilized */
#define BTCOD_MINOR_LAN_33				0x00000040	/* 17-33% utilized */
#define BTCOD_MINOR_LAN_50				0x00000060	/* 33-50% utilized */
#define BTCOD_MINOR_LAN_67				0x00000080	/* 50-67% utilized */
#define BTCOD_MINOR_LAN_83				0x000000A0	/* 67-83% utilized */
#define BTCOD_MINOR_LAN_99				0x000000C0	/* 83-99% utilized */
#define BTCOD_MINOR_LAN_NO_SERVICE		0x000000E0	/* 100% utilized */

/* Group: Minor Device Class - Audio Major class */
#define BTCOD_MINOR_AUDIO_UNCLASSIFIED	0x00000000
#define BTCOD_MINOR_AUDIO_HEADSET		0x00000004
#define BTCOD_MINOR_AUDIO_HANDSFREE		0x00000008
#define BTCOD_MINOR_AUDIO_MICROPHONE	0x00000010
#define BTCOD_MINOR_AUDIO_LOUDSPEAKER	0x00000014
#define BTCOD_MINOR_AUDIO_HEADPHONES	0x00000018
#define BTCOD_MINOR_AUDIO_PORTABLEAUDIO	0x0000001C
#define BTCOD_MINOR_AUDIO_CARAUDIO		0x00000020
#define BTCOD_MINOR_AUDIO_SETTOPBOX		0x00000024
#define BTCOD_MINOR_AUDIO_HIFIAUDIO		0x00000028
#define BTCOD_MINOR_AUDIO_VCR			0x0000002C
#define BTCOD_MINOR_AUDIO_VIDEOCAMERA	0x00000030
#define BTCOD_MINOR_AUDIO_CAMCORDER		0x00000034
#define BTCOD_MINOR_AUDIO_VIDEOMONITOR	0x00000038
#define BTCOD_MINOR_AUDIO_VIDEOSPEAKER	0x0000003C
#define BTCOD_MINOR_AUDIO_CONFERENCING	0x00000040
#define BTCOD_MINOR_AUDIO_GAMING		0x00000048

/* Group: Minor Device Class - Peripheral Major class */
#define BTCOD_MINOR_PERIPH_KEYBOARD		0x00000040
#define BTCOD_MINOR_PERIPH_POINTING		0x00000080
#define BTCOD_MINOR_PERIPH_COMBOKEY		0x000000C0

/* Group: Minor Device Class - ORed with Peripheral Minor Device class */
#define BTCOD_MINOR_PERIPH_UNCLASSIFIED	0x00000000
#define BTCOD_MINOR_PERIPH_JOYSTICK		0x00000004
#define BTCOD_MINOR_PERIPH_GAMEPAD		0x00000008
#define BTCOD_MINOR_PERIPH_REMOTECTRL	0x0000000C
#define BTCOD_MINOR_PERIPH_SENSING		0x00000010

/* Group: Minor Device Class - Imaging Major class */
#define BTCOD_MINOR_IMAGE_UNCLASSIFIED	0x00000000
#define BTCOD_MINOR_IMAGE_DISPLAY		0x00000010
#define BTCOD_MINOR_IMAGE_CAMERA		0x00000020
#define BTCOD_MINOR_IMAGE_SCANNER		0x00000040
#define BTCOD_MINOR_IMAGE_PRINTER		0x00000080

/* Group: Masks used to isolate the class of device components */
#define BTCOD_SERVICE_MASK				0x00ffC000	/* Less LIAC bit */
#define BTCOD_MAJOR_MASK				0x00001F00
#define BTCOD_MINOR_MASK				0x000000FC
#define BTCOD_LIMITED_DISC_MASK			0x00002000	/* LIAC bit */


/* --- SdpServiceClassUuid --- */

#define BTSDP_SERVICE_DISCOVERY_SERVER	0x1000
#define BTSDP_BROWSE_GROUP_DESC			0x1001
#define BTSDP_PUBLIC_BROWSE_GROUP		0x1002
#define BTSDP_SERIAL_PORT				0x1101
#define BTSDP_LAN_ACCESS_PPP			0x1102
#define BTSDP_DIALUP_NETWORKING			0x1103
#define BTSDP_IRMC_SYNC					0x1104
#define BTSDP_OBEX_OBJECT_PUSH			0x1105
#define BTSDP_OBEX_FILE_TRANSFER		0x1106
#define BTSDP_IRMC_SYNC_COMMAND			0x1107
#define BTSDP_HEADSET					0x1108
#define BTSDP_CORDLESS_TELEPHONY		0x1109
#define BTSDP_INTERCOM					0x1110
#define BTSDP_FAX						0x1111
#define BTSDP_HEADSET_AUDIO_GATEWAY		0x1112
#define BTSDP_PANU						0x1115
#define BTSDP_NAP						0x1116
#define BTSDP_GN						0x1117
#define BTSDP_HANDSFREE					0x111E
#define BTSDP_HANDSFREE_AUDIO_GATEWAY	0x111F
#define BTSDP_PNP_INFO					0x1200
#define BTSDP_GENERIC_NETWORKING		0x1201
#define BTSDP_GENERIC_FILE_TRANSFER		0x1202
#define BTSDP_GENERIC_AUDIO				0x1203
#define BTSDP_GENERIC_TELEPHONY			0x1204
#define BTSDP_HCR_PRINT					0x1126
#define BTSDP_HCR_SCAN					0x1127

/* --- Other definition --- */

#define BTDEF_NAME_LENGTH			82			/*	Bluetooth@햼̒				*/
#define BTDEF_ADDRESS_LENGTH		18			/*	Bluetooth@AhX̒			*/
#define BTDEF_PASSKEY_LENGTH		17			/*	pXL[̒iI[܂ށj		*/
#define BTDEF_MAX_PROFILE_NUM		16			/*	擾łvt@C̍ől	*/

#define BTDEF_MAX_INQUIRY_NUM		16			/*	InquiryŎ擾łnh̍ől	*/

/* --- structure define --- */

typedef struct _btstlocalinfo {
	TCHAR	LocalName[BTDEF_NAME_LENGTH];	/*	Bluetooth@햼					*/
	TCHAR	LocalAddress[BTDEF_ADDRESS_LENGTH];	/*	Bluetooth@AhX			*/
	LONG	LocalMode;							/*	BluetoothfoCX[h			*/
	LONG	LocalClass;							/*	BluetoothfoCXNX			*/
	BOOL	SecurityMode3;						/*	ZLeB[h3ݒtO	*/
	BOOL	Encryption;							/*	EncryptionݒtO			*/
} BTST_LOCALINFO;

typedef struct _btstdeviceinfo {
	HANDLE	DeviceHandle;						/*	BluetoothfoCXnh		*/
	TCHAR	DeviceName[BTDEF_NAME_LENGTH];	/*	Bluetooth@햼					*/
	TCHAR	DeviceAddress[BTDEF_ADDRESS_LENGTH];	/*	Bluetooth@AhX			*/
	LONG	DeviceClass;						/*	BluetoothfoCXNX			*/
	DWORD	ProfileNumber;						/*	gp\ȃvt@C		*/
	USHORT	ProfileType[BTDEF_MAX_PROFILE_NUM];	/*	gp\ȃvt@C̎	*/
} BTST_DEVICEINFO;

/* --- Function Prototype --- */

extern "C" {
	LONG BTLib_Initialize(void);
	LONG BTLib_DeInitialize(void);
	LONG BTLib_GetLocalInfo(BTST_LOCALINFO *);
	LONG BTLib_SetLocalInfo(BTST_LOCALINFO *);
	LONG BTLib_RegistLocalInfo(void);
	LONG BTLib_Inquiry(HANDLE *, DWORD *);
	LONG BTLib_GetDeviceHandle(HANDLE *, LPTSTR);
	LONG BTLib_GetDeviceInfo(BTST_DEVICEINFO *, HANDLE);
	LONG BTLib_GetServiceInfo(BTST_DEVICEINFO *);
	LONG BTLib_SelectDevice(BTST_DEVICEINFO *);
	LONG BTLib_SetPassKey(LPTSTR);
	LONG BTLib_CreateBond(BTST_DEVICEINFO *);
	LONG BTLib_RegistDeviceInfo(BTST_DEVICEINFO *);
	LONG BTLib_SearchDeviceInfo(BTST_DEVICEINFO *, DWORD *, LPTSTR);
	LONG BTLib_DeleteDeviceInfo(BTST_DEVICEINFO *);
	LONG BTLib_GetDefaultDeviceInfo(BTST_DEVICEINFO *);
	LONG BTLib_SetDefaultDevice(BTST_DEVICEINFO *);
}

/* --- End of Header File --- */
